---
title: "egse.exceptions"
---

!!! info "cgse-common"
    This code is part of the `cgse-common` package.


```text
Exception
 ├── CGSEException
 │    ├── Warning
 │    └── Error
 │        ├── InvalidOperationError
 │        ├── DeviceNotFoundError
 │        ├── InternalStateError
 │        └── DeviceError
 │             ├── DeviceControllerError
 │             ├── DeviceConnectionError
 │             ├── DeviceTimeoutError
 │             └── DeviceInterfaceError
 ├── Failure
 ├── HexapodError
 ├── PMACError
 ├── OGSEError
 ├── ESLError
 ├── FilterWheelError
 ├── FilterWheel8smc4Error
 ├── ShutterKSC1010Error
 ├── WindowSizeError
 ├── SettingsError
 └── StagesError
```

::: egse.exceptions
